@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "powerpc"
 #define HOST_VENDOR "apple"
-#define HOST_OS "macosx-10.3.9"
+#define HOST_OS "macosx-10.4.2"
 #define HOST_OS_NAME "macosx-10"
-#define HOST_OS_VERSION "10.3.9"
+#define HOST_OS_VERSION "10.4.2"
 #define HOST_ARCH "powerpc"
 #define DISTRO_NAME "none"
 #define HOST_NAME "a-osx.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu Aug 11 13:23:19 EDT 2005"
+#define CONFIG_DATE "Fri Oct  7 18:29:46 EDT 2005"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a1"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -34,15 +34,15 @@
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "10.3.9"
+#define HOST_HEADER_VERSION "10.4.2"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBLDAP 1
-#define HAVE_LDAP_ENABLE_CACHE 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
+#define HAVE_WAIT3 1
 #define GETPGRP_VOID 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
@@ -81,6 +81,8 @@
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STATVFS 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
@@ -148,6 +150,7 @@
 #define HAVE_SYS_SOCKET_H 1
 #define HAVE_SYS_SOCKIO_H 1
 #define HAVE_SYS_STAT_H 1
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_SYSLIMITS_H 1
 #define HAVE_SYS_SYSLOG_H 1
@@ -164,8 +167,6 @@
 #define HAVE_FCNTL_H 1
 #define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
-#define HAVE_LBER_H 1
-#define HAVE_LDAP_H 1
 #define HAVE_LIBGEN_H 1
 #define HAVE_LIMITS_H 1
 #define HAVE_MEMORY_H 1
@@ -185,6 +186,8 @@
 #define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_LBER_H 1
+#define HAVE_LDAP_H 1
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_darwin.h"
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -199,8 +202,8 @@
 #define MTYPE_TYPE char *
 #define MTYPE_PRINTF_TYPE "%s"
 #define YP_ORDER_OUTORDER_TYPE int
-#define RECVFROM_FROMLEN_TYPE int
-#define AUTH_CREATE_GIDLIST_TYPE gid_t
+#define RECVFROM_FROMLEN_TYPE socklen_t
+#define AUTH_CREATE_GIDLIST_TYPE int
 #define SVC_IN_ARG_TYPE caddr_t
 #define cdfs_args_t struct iso_args
 #define mfs_args_t struct mfs_args
@@ -208,6 +211,7 @@
 #define XDRPROC_T_TYPE xdrproc_t
 #define WORDS_BIGENDIAN 1
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -244,6 +248,10 @@
 #define HAVE_CDFS_ARGS_T_SSECTOR 1
 #define HAVE_UFS_ARGS_T_FSPEC 1
 #define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
+#define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
+#define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
 #define HAVE_NFS_ARGS_T_FHSIZE 1
 #define HAVE_NFS_ARGS_T_PROTO 1
 #define HAVE_NFS_ARGS_T_SOTYPE 1
@@ -291,15 +299,16 @@
 #define MNT2_GEN_OPT_QUOTA 0x2000
 #define MNT2_GEN_OPT_RDONLY 0x1
 #define MNT2_GEN_OPT_SYNCHRONOUS 0x2
-#define MNT2_NFS_OPT_DEADTHRESH 0x4000
+#define MNT2_NFS_OPT_ACDIRMAX 0x800000
+#define MNT2_NFS_OPT_ACDIRMIN 0x400000
+#define MNT2_NFS_OPT_ACREGMAX 0x200000
+#define MNT2_NFS_OPT_ACREGMIN 0x100000
 #define MNT2_NFS_OPT_DUMBTIMR 0x800
 #define MNT2_NFS_OPT_INT 0x40
 #define MNT2_NFS_OPT_KERB 0x400
-#define MNT2_NFS_OPT_LEASETERM 0x1000
 #define MNT2_NFS_OPT_MAXGRPS 0x20
 #define MNT2_NFS_OPT_NFSV3 0x200
 #define MNT2_NFS_OPT_NOCONN 0x80
-#define MNT2_NFS_OPT_NQNFS 0x100
 #define MNT2_NFS_OPT_RDIRPLUS 0x10000
 #define MNT2_NFS_OPT_READAHEAD 0x2000
 #define MNT2_NFS_OPT_READDIRSIZE 0x20000
@@ -313,3 +322,4 @@
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_LIBWRAP 1
